summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/ssimanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/liboscar/ssimanager.cpp')
-rw-r--r--kopete/protocols/oscar/liboscar/ssimanager.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kopete/protocols/oscar/liboscar/ssimanager.cpp b/kopete/protocols/oscar/liboscar/ssimanager.cpp
index 1351c237..630b8f6b 100644
--- a/kopete/protocols/oscar/liboscar/ssimanager.cpp
+++ b/kopete/protocols/oscar/liboscar/ssimanager.cpp
@@ -42,8 +42,8 @@ public:
WORD nextGroupId;
};
-SSIManager::SSIManager( TQObject *parent, const char *name )
- : TQObject( parent, name )
+SSIManager::SSIManager( TQObject *tqparent, const char *name )
+ : TQObject( tqparent, name )
{
d = new SSIManagerPrivate;
d->complete = false;
@@ -97,7 +97,7 @@ WORD SSIManager::nextContactId()
return 0xFFFF;
}
- if ( d->itemIdList.contains( d->nextContactId ) == 0 )
+ if ( d->itemIdList.tqcontains( d->nextContactId ) == 0 )
d->itemIdList.append( d->nextContactId );
return d->nextContactId++;
@@ -116,7 +116,7 @@ WORD SSIManager::nextGroupId()
return 0xFFFF;
}
- if ( d->groupIdList.contains( d->nextGroupId ) == 0 )
+ if ( d->groupIdList.tqcontains( d->nextGroupId ) == 0 )
d->groupIdList.append( d->nextGroupId );
return d->nextGroupId++;
@@ -141,7 +141,7 @@ void SSIManager::setParameters( WORD maxContacts, WORD maxGroups, WORD maxVisibl
{
//I'm not using k_funcinfo for these debug statements because of
//the function's long signature
- TQString funcName = TQString::fromLatin1( "[void SSIManager::setParameters] " );
+ TQString funcName = TQString::tqfromLatin1( "[void SSIManager::setParameters] " );
kdDebug(OSCAR_RAW_DEBUG) << funcName << "Max number of contacts allowed in SSI: "
<< maxContacts << endl;
kdDebug(OSCAR_RAW_DEBUG) << funcName << "Max number of groups allowed in SSI: "
@@ -214,7 +214,7 @@ Oscar::SSI SSIManager::findContact( const TQString &contact, const TQString &gro
return m_dummyItem;
}
- Oscar::SSI gr = findGroup( group ); // find the parent group
+ Oscar::SSI gr = findGroup( group ); // find the tqparent group
if ( gr.isValid() )
{
kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "gr->name= " << gr.name() <<
@@ -449,7 +449,7 @@ bool SSIManager::updateGroup( const Oscar::SSI& group )
d->SSIList.remove( oldGroup );
}
- if ( d->SSIList.findIndex( group ) != -1 )
+ if ( d->SSIList.tqfindIndex( group ) != -1 )
{
kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "New group is already in list." << endl;
return false;
@@ -496,7 +496,7 @@ bool SSIManager::removeGroup( const TQString &group )
bool SSIManager::newContact( const Oscar::SSI& contact )
{
- if ( d->SSIList.findIndex( contact ) == -1 )
+ if ( d->SSIList.tqfindIndex( contact ) == -1 )
{
kdDebug( OSCAR_RAW_DEBUG ) << k_funcinfo << "Adding contact '" << contact.name() << "' to SSI list" << endl;
addID( contact );
@@ -518,7 +518,7 @@ bool SSIManager::updateContact( const Oscar::SSI& contact )
d->SSIList.remove( oldContact );
}
- if ( d->SSIList.findIndex( contact ) != -1 )
+ if ( d->SSIList.tqfindIndex( contact ) != -1 )
{
kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "New contact is already in list." << endl;
return false;
@@ -562,7 +562,7 @@ bool SSIManager::removeContact( const TQString &contact )
bool SSIManager::newItem( const Oscar::SSI& item )
{
- if ( d->SSIList.findIndex( item ) != -1 )
+ if ( d->SSIList.tqfindIndex( item ) != -1 )
{
kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "Item is already in list." << endl;
return false;
@@ -584,7 +584,7 @@ bool SSIManager::updateItem( const Oscar::SSI& item )
d->SSIList.remove( oldItem );
}
- if ( d->SSIList.findIndex( item ) != -1 )
+ if ( d->SSIList.tqfindIndex( item ) != -1 )
{
kdDebug(OSCAR_RAW_DEBUG) << k_funcinfo << "New item is already in list." << endl;
return false;
@@ -614,12 +614,12 @@ void SSIManager::addID( const Oscar::SSI& item )
{
if ( item.type() == ROSTER_GROUP )
{
- if ( d->groupIdList.contains( item.gid() ) == 0 )
+ if ( d->groupIdList.tqcontains( item.gid() ) == 0 )
d->groupIdList.append( item.gid() );
}
else
{
- if ( d->itemIdList.contains( item.bid() ) == 0 )
+ if ( d->itemIdList.tqcontains( item.bid() ) == 0 )
d->itemIdList.append( item.bid() );
}
}
@@ -646,7 +646,7 @@ WORD SSIManager::findFreeId( const TQValueList<WORD>& idList, WORD fromId ) cons
{
for ( WORD id = fromId; id < 0x8000; id++ )
{
- if ( idList.contains( id ) == 0 )
+ if ( idList.tqcontains( id ) == 0 )
return id;
}